default_pages library

Optional ready-made pages. Import separately to opt in to these widgets.

For example: import 'package:route_definer/default_pages.dart' as default_router;

Classes

DeniedPage
Optional view for a guard's deny decision.
ErrorPage
Optional error view with pointer, keyboard and semantic retry actions.
LoadingPage
Optional loading view with a customizable, accessible message.
NotFoundPage
Optional view for a location without a matching definition.